:orphan:
Class Assignments
-----------------


This file allows you to create custom assignments for your class.  You write this file
using any valid restructuredText, including the directives that are used in the book.
For example if you want to have a homework problem where the students do some coding
you can do this:

Write a program that counts from 1 to 10

.. actex:: unique_id_1

   # your code here

